#
# spec file for package osmo-sip-connector
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2016-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           osmo-sip-connector
Version:        1.6.0
Release:        2.3
Summary:        MNCC to SIP bridge for osmo-nitb
License:        AGPL-3.0-or-later AND GPL-2.0-or-later
Group:          Productivity/Telephony/Servers
URL:            http://openbsc.osmocom.org/
Source:         %{name}-%{version}.tar.xz
Patch0:         harden_osmo-sip-connector.service.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.20
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libosmocore) >= 1.5.0
BuildRequires:  pkgconfig(libosmogsm) >= 1.5.0
BuildRequires:  pkgconfig(libosmovty) >= 1.5.0
BuildRequires:  pkgconfig(sofia-sip-ua-glib) >= 1.12.0
%{?systemd_requires}

%description
Use the osmo-nitb MNCC interface and bridge it to SIP.

%prep
%autosetup -p1

%build
echo "%{version}" >.tarball-version
autoreconf -fi
%configure \
  --docdir="%{_docdir}/%{name}" \
  --with-systemdsystemunitdir=%{_unitdir}
make %{?_smp_mflags}

%install
%make_install
install -d %{buildroot}/%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rc%{name}

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%check
make %{?_smp_mflags} check || (find . -name testsuite.log -exec cat {} +)

%files
%license COPYING
%doc README.asciidoc
%doc %{_docdir}/%{name}/examples
%{_bindir}/osmo-sip-connector
%dir %{_sysconfdir}/osmocom
%config(noreplace) %{_sysconfdir}/osmocom/osmo-sip-connector.cfg
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Fri Nov 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.6.0
  * https://git.osmocom.org/osmo-sip-connector/plain/debian/changelog?h=1.6.0
* Wed Oct 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_osmo-sip-connector.service.patch
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.4.0
  * MNCC v6: add optional SDP to the socket protocol
- Update to new upstream release 1.3.0
  * Logging: Make use of Levels, clarify some messages
  * Add support for MNCC HOLD/RETRIEVE
  * Handle SIP re-INVITEs
  * MNCC: Do not continue with B leg if A leg is cancelled.
  * Added daemonize feature to osmo-sip-connector
  * Support Emergency Calling
  * Support International Caller ID
* Wed Jan 30 2019 mardnh@gmx.de
- Update to new upstream release 1.2.0
  * various logging improvements (more strings, less numbers)
  * better SIP/MNCC cause mapping
  * Full changelog:
    http://git.osmocom.org/osmo-sip-connector/plain/debian/changelog?h=1.2.0
- Remove patches:
  * 0001-contrib-Add-systemd-service-file.patch
* Sat Mar 17 2018 mardnh@gmx.de
- Use use the systemd service file from contrib/
- Show testsuite.log when tests are failing
* Fri Dec 29 2017 jengelh@inai.de
- %%service_* already takes care of restart/removal
* Wed Dec 27 2017 mardnh@gmx.de
- Minor specfile cleanup
* Wed Dec 27 2017 mardnh@gmx.de
- Update to new upstream release 1.1.0
  * No changelog was provided
* Wed Feb 15 2017 mardnh@gmx.de
- Update to version 0.0.0.git1486793192.42b073a:
  * sip: Treat SIP 183 as progress too
  * evpoll: Use {} in the middle of the if/else if/else block
  * evpoll: Always initialize revents for the output
  * evpoll: Don't try to be more smart than g_poll
* Sun Dec 25 2016 mardnh@gmx.de
- Update to version 0.0.0.git1475798073.fffc742:
  * build: be robust against install-sh files above the root dir
  * configure: check for pkg-config presence
  * jenkins.sh: use osmo-build-dep.sh, log test failures
* Sun Oct  2 2016 mardnh@gmx.de
- Update to version 0.0.0.git1474923387.c403ed6:
  * app/mncc: Add "use-imsi" to allow calling by IMSI
  * mncc: Only copy 15 chars to leave the last one as NULL
  * mncc: Have all release go through a local method
  * mncc: Reject hold requests for now
  * mncc: Use snprintf correctly create format specifier
  * vty: Add simple VTY output for current calls
  * vty: Fix the number of documented arguments
  * sip/call/mncc: Move source/dest into the call structure
  * vty: Add extended show calls command with all information
  * mncc: Use strcpy for these routines and not memcpy
  * vty: Add VTY command about the state of the mncc connection
  * jenkins: Add first CI script for the SIP connector
  * distcheck/tests: Add the referenced osmoappdesc.py for testing
  * distcheck: Package the logging.h file as well
  * jenkins: Try to enable the vty tests as well
  * jenkins: Use separate check invocation tor un the tests
  * jenkins: Make it find the libosmocore library as well
  * sip: Start the application even if sofia-sip is broken
  * log VTY telnet bind only once
* Thu Mar 31 2016 mardnh@gmx.de
- initial package
